package common;

/**
 * Represent a location on the board
 * 
 */
public class Location {

	private int column;
	private int row;

	public Location(int row, int column) {
		this.row = row;
		this.column = column;
	}

	/**
	 * Copies another location
	 * 
	 * @param other
	 *            the location to copy
	 */
	public Location(Location other) {
		this(other.getRow(), other.getColumn());
	}

	public int getRow() {
		return row;
	}

	public int getColumn() {
		return column;
	}

	/**
	 * Moves the current location to another, absolute, position
	 * 
	 * @param other
	 *            the location to move to
	 */
	public void moveTo(Location other) {
		this.row = other.row;
		this.column = other.column;
	}

	/**
	 * @param rows
	 *            The delta, in rows, of the target position
	 * @param columns
	 *            The delta, in columns, of the target position
	 * @return A new position relative to the current one
	 */
	public Location offset(int rows, int columns) {
		int targetRow = row + rows;
		int targetFile = column + columns;

		return new Location(targetRow, targetFile);
	}

	/**
	 * Returns a string representation of the current location. Rows are
	 * numbered from 1 to 8 and columns are marked 'a' to 'h'.
	 */
	@Override
	public String toString() {
		return String.format("%c%c", (char) ('a' + column), (char) ('1' + row));
	}

	@Override
	public int hashCode() {
		final int prime = 31;
		int result = 1;
		result = prime * result + column;
		result = prime * result + row;
		return result;
	}

	@Override
	public boolean equals(Object obj) {
		if (this == obj)
			return true;
		if (obj == null)
			return false;
		if (getClass() != obj.getClass())
			return false;
		Location other = (Location) obj;
		if (column != other.column)
			return false;
		if (row != other.row)
			return false;
		return true;
	}

}
