package common;

import java.util.Set;

/**
 * An interface to represent a piece in a board game
 * 
 */
public interface Piece {
	/**
	 * @return The location of the piece on the board
	 */
	public Location getLocation();

	/**
	 * @param board
	 *            The board state
	 * @return the available moves of this piece given the current positioning
	 *         of other pieces
	 */
	public Set<Move> getPossibleMoves(Board board);

	/**
	 * @param board
	 *            The board state
	 * @return the available captures to this piece, assuming the previous move
	 *         was a capture
	 */
	public Set<Move> getNextCapture(Board board);

	/**
	 * @return The player owning this piece (or, equivalently, the color of the
	 *         piece)
	 */
	public Player getPlayer();
}
