package ui;

import java.awt.BorderLayout;
import java.awt.EventQueue;
import java.awt.event.ActionEvent;
import java.awt.event.ActionListener;
import java.util.Map;
import java.util.Set;

import javax.swing.JButton;
import javax.swing.JFrame;
import javax.swing.JToolBar;
import javax.swing.UIManager;

import checkers.Game;

import common.Move;
import common.Piece;

/**
 * The main class for the checkers application
 * 
 */
public class Application implements LocationSelectionListener {

	/**
	 * The main window
	 */
	private JFrame frame;
	/**
	 * The game
	 */
	private Game game = new Game();
	/**
	 * The board panel (UI). This serves for both input (mouse clicks) and
	 * output (graphics of the board state)
	 */
	private BoardPanel board;
	/**
	 * A list of the currently available moves
	 */
	private Map<Piece, Set<Move>> availableMoves;

	/**
	 * Launch the application.
	 */
	public static void main(String[] args) {
		try {
			UIManager.setLookAndFeel(UIManager.getSystemLookAndFeelClassName());
		} catch (Exception e) {
			System.out.println("Error while setting native LAF: " + e);
		}

		EventQueue.invokeLater(new Runnable() {
			public void run() {
				try {
					Application window = new Application();
					window.frame.setVisible(true);
				} catch (Exception e) {
					e.printStackTrace();
				}
			}
		});
	}

	/**
	 * Create the application.
	 */
	public Application() {
		initialize();
		initializeGame();
	}

	/**
	 * Initialize a a new game
	 */
	private void initializeGame() {
		game = new Game();
		board.setGame(game);
		availableMoves = game.getAvailableMoves();
		board.highlightPieces(availableMoves.keySet());
	}

	/**
	 * Initialize the contents of the frame.
	 */
	private void initialize() {
		frame = new JFrame();
		frame.setBounds(100, 100, 500, 500);
		frame.setDefaultCloseOperation(JFrame.EXIT_ON_CLOSE);
		frame.setTitle("Checkers");

		JToolBar toolBar = new JToolBar();
		frame.getContentPane().add(toolBar, BorderLayout.NORTH);

		JButton btnNewGame = new JButton("New game");
		btnNewGame.addActionListener(new ActionListener() {
			public void actionPerformed(ActionEvent e) {
				initializeGame();
			}
		});
		toolBar.add(btnNewGame);

		board = new BoardPanel();
		board.addLocationListener(this);

		frame.getContentPane().add(board, BorderLayout.CENTER);
	}

	@Override
	public void locationSelected(BoardPanel sender, LocationSelectedEvent event) {
		// TODO: implement this method
	}

}
